@@ -1,4 +1,5 @@
 __all__ = ['topic', 'trace_elimination', 'music_score_recognition', 'speech_recognition_english',
            'speech_recognition_chinese', 'region_marquee', 'fluorescent_pen_recognition', 'photo_to_cartoon',
            'skin_recognition', 'watermark_removal', 'ocr_rec', 'paper_rotation', 'speech_synthesis', 'topic_loc',
-           'teacher_qualification_check', 'object_detection']
+           'teacher_qualification_check', 'object_detection', 'image_search', 'cutout_and_beauty',
+           'idphoto_deep_beauty_to_b']
